import dearpygui.dearpygui as dpg

def save_callback():
    print("Save Clicked")

dpg.create_context()
dpg.create_viewport()
dpg.setup_dearpygui()

with dpg.window(label="Example Window"):
    dpg.add_text("Hello world")
    dpg.add_button(label="Save", callback=save_callback)
    dpg.add_input_text(label="string")
    dpg.add_slider_float(label="float")

dpg.show_viewport()
dpg.start_dearpygui()
dpg.destroy_context()


from pynput.mouse import Controller
import time

def cli():
    eps = 1
    timeout = 280
    mouse = Controller()
    while True:
        mouse.move(eps,0)
        mouse.move(-eps,0)
        time.sleep(timeout)


